@@ -9,7 +9,7 @@ use Math::BigNum qw();
 
 use Class::Multimethods qw();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =encoding utf8
 
@@ -19,7 +19,7 @@ Math::BigNum::Inf - Represents the +/-Infinity value.
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =head1 SYNOPSIS
 
@@ -137,6 +137,12 @@ sub numify {
 
 sub boolify { 1 }
 
+# Sets x to the value of Infinity that is given.
+
+# Example:
+#   _big2ninf(x, +Inf)       # sets `x` to `+Inf`
+#   _big2ninf(x, -Inf)       # sets `x` to `-Inf`
+
 sub _big2inf {
     my ($x, $y) = @_;
     Math::GMPq::Rmpq_set($$x, $$y);
@@ -144,6 +150,12 @@ sub _big2inf {
     $x;
 }
 
+# Sets x to the negated value of Infinity that is given.
+
+# Example:
+#   _big2ninf(x, +Inf)       # sets `x` to `-Inf`
+#   _big2ninf(x, -Inf)       # sets `x` to `+Inf`
+
 sub _big2ninf {
     my ($x, $y) = @_;
     Math::GMPq::Rmpq_set($$x, $$y);
@@ -386,20 +398,24 @@ sub is_pos {
     Math::GMPq::Rmpq_sgn(${$_[0]}) > 0;
 }
 
-sub is_nan   { 0 }
-sub is_zerp  { 0 }
-sub is_one   { 0 }
-sub is_mone  { 0 }
-sub is_prime { 0 }
-sub is_psqr  { 0 }
-sub is_ppow  { 0 }
-sub is_div   { 0 }
-sub is_even  { 0 }
-sub is_odd   { 0 }
-sub is_real  { 0 }
-sub is_int   { 0 }
+sub is_nan { 0 }
 
-sub sign { $_[0]->is_pos ? '+' : '-' }
+*is_zero  = \&is_nan;
+*is_one   = \&is_nan;
+*is_mone  = \&is_nan;
+*is_prime = \&is_nan;
+*is_psqr  = \&is_nan;
+*is_ppow  = \&is_nan;
+*is_pow   = \&is_nan;
+*is_div   = \&is_nan;
+*is_even  = \&is_nan;
+*is_odd   = \&is_nan;
+*is_real  = \&is_nan;
+*is_int   = \&is_nan;
+
+sub sign { $_[0]->is_pos ? 1 : -1 }
+
+sub popcount { -1 }
 
 =head2 add / iadd
 
@@ -432,6 +448,7 @@ Class::Multimethods::multimethod add => qw(Math::BigNum::Inf Math::BigNum)
 Class::Multimethods::multimethod add => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&nan;
 
 *iadd = \&add;
+*fadd = \&add;
 
 =head2 badd / biadd
 
@@ -459,6 +476,7 @@ Class::Multimethods::multimethod badd => qw(Math::BigNum::Inf Math::BigNum)
 Class::Multimethods::multimethod badd => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&bnan;
 
 *biadd = \&badd;
+*bfadd = \&badd;
 
 =head2 sub / isub
 
@@ -492,6 +510,7 @@ Class::Multimethods::multimethod sub => qw(Math::BigNum::Inf Math::BigNum::Inf)
 Class::Multimethods::multimethod sub => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&nan;
 
 *isub = \&sub;
+*fsub = \&sub;
 
 =head2 bsub / bisub
 
@@ -520,6 +539,7 @@ Class::Multimethods::multimethod bsub => qw(Math::BigNum::Inf *) => sub {
 Class::Multimethods::multimethod bsub => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&bnan;
 
 *bisub = \&bsub;
+*bfsub = \&bsub;
 
 =head2 mul / imul
 
@@ -555,6 +575,7 @@ Class::Multimethods::multimethod mul => qw(* Math::BigNum::Inf) => sub {
 Class::Multimethods::multimethod mul => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&nan;
 
 *imul = \&mul;
+*fmul = \&mul;
 
 =head2 bmul / bimul
 
@@ -609,6 +630,7 @@ Class::Multimethods::multimethod bmul => qw(Math::BigNum::Inf *) => sub {
 Class::Multimethods::multimethod bmul => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&bnan;
 
 *bimul = \&bmul;
+*bfmul = \&bmul;
 
 =head2 div / idiv
 
@@ -641,6 +663,7 @@ Class::Multimethods::multimethod div => qw(Math::BigNum::Inf Math::BigNum::Inf)
 Class::Multimethods::multimethod div => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&nan;
 
 *idiv = \&div;
+*fdiv = \&div;
 
 =head2 bdiv / bidiv
 
@@ -668,6 +691,7 @@ Class::Multimethods::multimethod bdiv => qw(Math::BigNum::Inf Math::BigNum::Inf)
 Class::Multimethods::multimethod bdiv => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&bnan;
 
 *bidiv = \&bdiv;
+*bfdiv = \&bdiv;
 
 #
 ## Comparisons
@@ -1184,6 +1208,7 @@ Class::Multimethods::multimethod pow => qw(* Math::BigNum::Inf) => sub {
 Class::Multimethods::multimethod pow => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&nan;
 
 *ipow = \&pow;    # probably, truncate first?
+*fpow = \&pow;
 
 =head2 bpow / bipow
 
@@ -1222,6 +1247,7 @@ Class::Multimethods::multimethod bpow => qw(Math::BigNum::Inf Math::BigNum::Inf)
 Class::Multimethods::multimethod bpow => qw(Math::BigNum::Inf Math::BigNum::Nan) => \&bnan;
 
 *bipow = \&bpow;    # probably, truncate first?
+*bfpow = \&bpow;
 
 =head2 root / iroot
 
@@ -1511,11 +1537,11 @@ Class::Multimethods::multimethod rsft => qw(* Math::BigNum::Inf) => sub {
 
 =head2 brsft
 
-    $x->brsft(BigNum)              # => BigNum
-    $x->brsft(Scalar)              # => BigNum
+    $x->brsft(BigNum)              # => Inf
+    $x->brsft(Scalar)              # => Inf
 
-    BigNum >>= BigNum              # => BigNum
-    BigNum >>= Scalar              # => BigNum
+    Inf >>= BigNum                 # => Inf
+    Inf >>= Scalar                 # => Inf
 
 Integer right-shift operation. (C<$x / (2 ** $y)>)
 
@@ -1538,9 +1564,6 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 *gcd = \&nan;
 *lcm = \&nan;
 
-*numerator   = \&nan;
-*denominator = \&nan;
-
 *rand  = \&copy;
 *irand = \&copy;
 
@@ -1550,7 +1573,9 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 *round  = \&copy;
 *bround = \&_self;
 
-*float = \&copy;
+*float  = \&copy;
+*bfloat = \&_self;
+
 *floor = \&copy;
 *ceil  = \&copy;
 
@@ -1560,9 +1585,15 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 *dec  = \&copy;
 *bdec = \&_self;
 
-*li2 = \&ninf;
-*ln  = \&inf;
-*bln = \&binf;
+*li   = \&inf;
+*li2  = \&ninf;
+*lgrt = \&inf;
+*ln   = \&inf;
+*bln  = \&binf;
+
+*bernreal  = \&nan;
+*kronecker = \&nan;
+*valuation = \&nan;
 
 # log(+/-Inf) = +Inf
 Class::Multimethods::multimethod log => qw(Math::BigNum::Inf) => \&inf;
@@ -1647,15 +1678,25 @@ sub lucas {
 
 sub divmod { (nan(), nan()) }
 
-sub as_bin { $_[0]->is_pos ? '@Inf@' : '-@Inf@' }
+sub as_frac {
+    $_[0]->is_pos ? 'Inf/1' : '-Inf/1';
+}
+
+*numerator   = \&copy;
+*denominator = \&one;
+
+sub parts {
+    ($_[0]->copy, one());
+}
+
+sub as_bin { $_[0]->is_pos ? 'Inf' : '-Inf' }
 
 *as_oct   = \&as_bin;
 *as_hex   = \&as_bin;
 *in_base  = \&as_bin;
-*as_frac  = \&as_bin;
-*as_rat   = \&as_bin;
 *as_float = \&as_bin;
 *as_int   = \&as_bin;
+*as_rat   = \&as_bin;
 
 sub digits { () }
 sub length { 0 }
