@@ -7,7 +7,7 @@ use warnings;
 use Math::GMPq qw();
 use Math::BigNum qw();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =encoding utf8
 
@@ -17,7 +17,7 @@ Math::BigNum::Nan - Represents the Not-a-Number value.
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =head1 SYNOPSIS
 
@@ -130,7 +130,7 @@ sub bnan {
     $x;
 }
 
-sub in_base { '@NaN@' }
+sub in_base { 'NaN' }
 
 =head2 eq
 
@@ -189,8 +189,10 @@ Always returns Nan.
 
 *add   = \&nan;
 *iadd  = \&nan;
+*fadd  = \&nan;
 *badd  = \&_self;
 *biadd = \&_self;
+*bfadd = \&_self;
 
 =head2 sub / bsub
 
@@ -203,8 +205,10 @@ Always returns Nan.
 
 *sub   = \&nan;
 *isub  = \&nan;
+*fsub  = \&nan;
 *bsub  = \&_self;
 *bisub = \&_self;
+*bfadd = \&_self;
 
 =head2 mul / bmul
 
@@ -217,8 +221,10 @@ Always returns Nan.
 
 *mul   = \&nan;
 *imul  = \&nan;
+*fmul  = \&nan;
 *bmul  = \&_self;
 *bimul = \&_self;
+*bfmul = \&_self;
 
 =head2 div / bdiv
 
@@ -231,8 +237,10 @@ Always returns Nan.
 
 *div   = \&nan;
 *idiv  = \&nan;
+*fdiv  = \&nan;
 *bdiv  = \&_self;
 *bidiv = \&_self;
+*bfdiv = \&_self;
 
 =head2 pow / ipow / bpow / bipow
 
@@ -244,9 +252,11 @@ Always returns Nan.
 =cut
 
 *pow   = \&nan;
-*bpow  = \&_self;
 *ipow  = \&nan;
+*fpow  = \&nan;
+*bpow  = \&_self;
 *bipow = \&_self;
+*bfpow = \&_self;
 
 =head2 mod / imod / bmod / bimod
 
@@ -258,9 +268,11 @@ Always returns Nan.
 =cut
 
 *mod   = \&nan;
-*bmod  = \&_self;
 *imod  = \&nan;
+*fmod  = \&nan;
+*bmod  = \&_self;
 *bimod = \&_self;
+*bfmod = \&_self;
 
 =head2 fac / bfac
 
@@ -301,6 +313,9 @@ sub cmp { }
 *lt = \&cmp;
 *le = \&cmp;
 
+*popcount = \&cmp;
+*sign     = \&cmp;
+
 # Other methods
 
 *sqrt  = \&nan;
@@ -356,6 +371,7 @@ sub cmp { }
 *coth  = \&nan;
 *acoth = \&nan;
 *atan2 = \&nan;
+*lgrt  = \&nan;
 
 *rand   = \&nan;
 *irand  = \&nan;
@@ -363,46 +379,48 @@ sub cmp { }
 *inv    = \&nan;
 *binv   = \&_self;
 
+sub is_nan { 1 }
+
 sub is_zero { 0 }
-sub is_one  { 0 }
-sub is_mone { 0 }
-sub is_pos  { 0 }
-sub is_neg  { 0 }
-sub is_int  { 0 }
-sub is_real { 0 }
-sub is_inf  { 0 }
-sub is_ninf { 0 }
-sub is_nan  { 1 }
-sub is_even { 0 }
-sub is_odd  { 0 }
-sub is_div  { 0 }
-sub is_psqr { 0 }
-sub is_ppow { 0 }
-sub sign    { '' }
+
+*is_one   = \&is_zero;
+*is_mone  = \&is_zero;
+*is_pos   = \&is_zero;
+*is_neg   = \&is_zero;
+*is_int   = \&is_zero;
+*is_real  = \&is_zero;
+*is_inf   = \&is_zero;
+*is_ninf  = \&is_zero;
+*is_even  = \&is_zero;
+*is_odd   = \&is_zero;
+*is_div   = \&is_zero;
+*is_psqr  = \&is_zero;
+*is_ppow  = \&is_zero;
+*is_pow   = \&is_zero;
+*is_prime = \&is_zero;
 
 *max = \&_self;
 *min = \&_self;
 
-*gcd   = \&nan;
-*lcm   = \&nan;
-*int   = \&nan;
-*bint  = \&_self;
-*float = \&nan;
+*gcd  = \&nan;
+*lcm  = \&nan;
+*int  = \&nan;
+*bint = \&_self;
 
-sub as_frac  { '' }
-sub as_rat   { '' }
-sub as_float { '' }
-sub as_int   { '' }
-sub as_bin   { '' }
-sub as_hex   { '' }
-sub as_oct   { '' }
+*float  = \&nan;
+*bfloat = \&_self;
+
+sub as_frac  { '0/0' }
+sub as_rat   { '0/0' }
+sub as_float { 'NaN' }
+sub as_int   { 'NaN' }
+sub as_bin   { 'NaN' }
+sub as_hex   { 'NaN' }
+sub as_oct   { 'NaN' }
 
 sub digits { () }
 sub length { 0 }
 
-*numerator   = \&nan;
-*denominator = \&nan;
-
 *floor  = \&nan;
 *ceil   = \&nan;
 *round  = \&nan;
@@ -433,11 +451,12 @@ sub length { 0 }
 *rsft  = \&nan;
 *brsft = \&_self;
 
-*dfac     = \&nan;
-*lucas    = \&nan;
-*binomial = \&nan;
-
-sub is_prime { 0 }
+*dfac      = \&nan;
+*lucas     = \&nan;
+*binomial  = \&nan;
+*bernreal  = \&nan;
+*kronecker = \&nan;
+*valuation = \&nan;
 
 *next_prime = \&nan;    # next prime after NaN? Hmm...
 *agm        = \&nan;
@@ -450,8 +469,14 @@ sub is_prime { 0 }
 *erf        = \&nan;
 *erfc       = \&nan;
 *eint       = \&nan;
+*li         = \&nan;
 *li2        = \&nan;
 
+*numerator   = \&nan;
+*denominator = \&nan;
+
 sub divmod { (nan(), nan()) }
 
+*parts = \&divmod;
+
 1;
